import os
import re
import sys


repo_name = os.getenv("repo_name")
# print(repo_name)
if repo_name is not None:
    match_obj = re.search(
        r"idrl-assignment/3-simplelayout-package-(.*)", repo_name
    )
    if match_obj:
        user_name = match_obj.group(1)
        print(user_name)
    else:
        sys.exit("No match!")
else:
    sys.exit("No repo name!")



import argparse
import os
import sys

def get_options():
    # TODO: 按 1-simplelayout-CLI 要求添加相应参数
    parser = argparse.ArgumentParser()
    parser.add_argument('--board_grid', type=int)
    parser.add_argument('--unit_grid', type=int)
    parser.add_argument('--unit_n', type=int)
    parser.add_argument('--positinons', type=int, nargs = '+')
    parser.add_argument('--outdir', type=str)
    parser.add_argument('--file_name', type=str)
    options = parser.parse_args()
    if options.board_grid % options.unit_grid or len(options.positions) != options.unit_n:
        sys.exit()
    for i in options.positions:
        if i < 1 or i > (options.board_grid / options.unit_grid) ** 2:
            sys.exit()
    path = options.outdir
    if not os.path.exists(path):
        os.makedirs(path)
    return 



"""
辅助函数
"""

#from pathlib import Path
import matplotlib.pyplot as plt
import scipy.io as sio
import os

def save_matrix(matrix, file_name):
    # TODO: 存储 matrix 到 file_name.mat, mdict 的 key 为 "matrix"
    sio.savemat(file_name + '.mat', {'matrix': matrix})  
    return

def save_fig(matrix, file_name):
    # TODO: 将 matrix 画图保存到 file_name.jpg
    plt.imsave(file_name + '.jpg', matrix)
    return


def make_dir(outdir):
    # TODO: 当目录 outdir 不存在时创建目录
    if not os.path.exists(outdir):
        os.makedirs(outdir)
    return



import setuptools

setuptools.setup(
      name='simplelayout-stc950502',  # 程序名称
      version='1.0',  # 程序版本号
      author='stc',  # 程序作者
      description='generator',  # 程序描述
      packages= setuptools.find_namespace_packages(),
      install_requires=[
      'simplelayout'],
      entry_points = {
        'console_scripts': [
            'simplelayout = src.simplelayout:main',
        ]}
      )



"""
数据生成的主要逻辑
"""


import numpy as np


def generate_matrix(
    board_grid: int, unit_grid: int, unit_n: int, positions: list
) -> np.ndarray:
    """生成指定布局矩阵

    Args:
        board_grid (int): 布局板分辨率，代表矩形区域的边长像素数
        unit_grid (int): 矩形组件分辨率
        unit_n (int): 组件数
        positions (list): 每个元素代表每个组件的位置
    Returns:
        np.ndarray: 布局矩阵
    """ 
    n = int(board_grid/unit_grid)
    s = (board_grid, board_grid)
    a = np.zeros(s, dtype=int)
    for i in range(0,unit_n):
        a_1 = int((positions[i]-1)/n)
        a_2 = int((positions[i]-n*a_1)/n)
        a[unit_grid*a_1:unit_grid*(a_1+1), unit_grid*a_2:unit_grid*(a_2+1)] = 1
    return a